@@ -15,7 +15,6 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,USA.
 
 
-import imp
 import os
 import re
 import shutil
@@ -25,12 +24,15 @@ import tarfile
 import tempfile
 import unittest
 
-
 from ddt import data, ddt, unpack
 
+from loader import import_set_version
 
-# NOTE(toabctl): Hack to import non-module file for testing
-sv = imp.load_source("set_version", "set_version")
+DEBUG = False
+if os.environ.get('DEBUG_SET_VERSION') == "1":
+    DEBUG = True
+
+sv = import_set_version()
 
 
 SET_VERSION_EXECUTABLE = os.path.abspath(
@@ -97,12 +99,16 @@ class SetVersionBaseTest(unittest.TestCase):
             shutil.rmtree(self._tmpoutdir)
         except subprocess.CalledProcessError as e:
             raise Exception(
-                "Can not call '%s' in dir '%s'. Error: %s" % ("".join(cmd),
+                "Can not call '%s' in dir '%s'. Error: %s" % (" ".join(cmd),
                                                               self._tmpdir,
                                                               e.output))
 
     def tearDown(self):
-        shutil.rmtree(self._tmpdir)
+        if DEBUG:
+            print("DEBUG_SET_VERSION enabled: Please remove '%s' manually."
+                  % self._tmpdir)
+        else:
+            shutil.rmtree(self._tmpdir)
 
 
 @ddt
@@ -257,11 +263,11 @@ class TestSetVersionBasics(SetVersionBaseTest):
         files_local = ['test-v1.2.3.tar']
 
         # checking dirname in archive detection
-        args = {'regex': '^test-v(.*)', 'basename': ''}
+        args = {'regex': '^test-v(.*)', 'basename': '', 'fromfile': None}
         ver = sv._version_detect(args, files_local)
         self.assertEqual(ver, '1.2.3')
 
         # checking archive filename detection
-        args = {'regex': '^test-v(.*).tar', 'basename': ''}
+        args = {'regex': '^test-v(.*).tar', 'basename': '', 'fromfile': None}
         ver = sv._version_detect(args, files_local)
         self.assertEqual(ver, '1.2.3')
